import { getUser, logout, getUserPermissions } from '@/api/common'
import router, { resetRouter } from '@/router'
const user = {
  state: {
    user: {},
    isLogin: false,
    roles: null,
    permissions: null
  },

  mutations: {
    setUser(state, user) {
      state.user = user
    },
    setIsLogin(state, isLogin) {
      state.isLogin = isLogin
    },
    setRoles(state, roles) {
      state.roles = roles
    },
    setPermissions(state, permissions) {
      state.permissions = permissions
    }
  },

  actions: {
    // 退出登录
    logout({ commit }) {
      return logout().then(response => {
        commit('setUser', {})
        commit('setIsLogin', false)
        commit('setPermissions', null)
        resetRouter()
        return response
      })
    },
    // 检测登录状态
    async checkLogin({ commit }) {
      const isLogin = await getUser()
        .then(response => {
          commit('setUser', response.data)
          return true
        })
        .catch(() => {
          commit('setUser', {})
          return false
        })
      commit('setIsLogin', isLogin)
      return isLogin
    },
    // 检测角色权限
    async checkRolesPermissions({ commit }) {
      const obj = await getUserPermissions().then(res => {
        if (res.code === 0) {
          const data = res.data
          let permissions = []
          if (data.permissions && Array.isArray(data.permissions)) {
            permissions = data.permissions
          }
          commit('setPermissions', permissions)
          return {
            permissions
          }
        } else {
          return {}
        }
      }).catch(() => {
        commit('setPermissions', null)
        return {}
      })
      return obj
    },
    // 刷新路由与菜单
    async updateRoutes({ state, dispatch }) {
      const permissions = state.permissions
      // 基于权限获取可接入的路由
      const accessRoutes = await dispatch('permission/routesByPermissions', permissions)
      // 重新设置路由
      resetRouter()
      // 动态添加路由
      router.addRoutes(accessRoutes)
    }
  }
}

export default user
